@@ -52,11 +52,12 @@ typedef struct r_flag_t {
 	st64 base;         /* base address for all flag items */
 	int space_idx;     /* index of the selected space in spaces array */
 	bool space_strict; /* when true returned flag items must belong to the selected space */
+	bool realnames;
 	char *spaces[R_FLAG_SPACES_MAX]; /* array of flag spaces */
 	Sdb *tags;
 	RNum *num;
 	RSkipList *by_off; /* flags sorted by offset, value=RFlagsAtOffset */
-	SdbHash *ht_name; /* hashmap key=item name, value=RList of items */
+	HtPP *ht_name; /* hashmap key=item name, value=RList of items */
 	RList *flags;   /* list of RFlagItem contained in the flag */
 	RList *spacestack;
 	PrintfCallback cb_printf;
@@ -73,7 +74,12 @@ typedef bool (*RFlagExistAt)(RFlag *f, const char *flag_prefix, ut16 fp_size, ut
 typedef RFlagItem* (*RFlagGet)(RFlag *f, const char *name);
 typedef RFlagItem* (*RFlagGetAt)(RFlag *f, ut64 addr, bool closest);
 typedef RFlagItem* (*RFlagSet)(RFlag *f, const char *name, ut64 addr, ut32 size);
+typedef bool (*RFlagUnset)(RFlag *f, RFlagItem *item);
+typedef bool (*RFlagUnsetName)(RFlag *f, const char *name);
+typedef bool (*RFlagUnsetOff)(RFlag *f, ut64 addr);
 typedef int (*RFlagSetSpace)(RFlag *f, const char *name);
+typedef bool (*RFlagPopSpace)(RFlag *f);
+typedef bool (*RFlagPushSpace)(RFlag *f, const char *name);
 
 typedef struct r_flag_bind_t {
 	int init;
@@ -82,11 +88,16 @@ typedef struct r_flag_bind_t {
 	RFlagGet get;
 	RFlagGetAt get_at;
 	RFlagSet set;
+	RFlagUnset unset;
+	RFlagUnsetName unset_name;
+	RFlagUnsetOff unset_off;
 	RFlagSetSpace set_fs;
+	RFlagPushSpace push_fs;
+	RFlagPopSpace pop_fs;
 } RFlagBind;
 
 #define r_flag_bind_init(x) memset(&x,0,sizeof(x))
-R_API int r_flag_bind(RFlag *io, RFlagBind *bnd);
+R_API void r_flag_bind(RFlag *io, RFlagBind *bnd);
 
 #ifdef R_API
 R_API RFlag * r_flag_new(void);
@@ -99,13 +110,13 @@ R_API RFlagItem *r_flag_get_i2(RFlag *f, ut64 off);
 R_API RFlagItem *r_flag_get_at(RFlag *f, ut64 off, bool closest);
 R_API const RList* /*<RFlagItem*>*/ r_flag_get_list(RFlag *f, ut64 off);
 R_API char *r_flag_get_liststr(RFlag *f, ut64 off);
-R_API int r_flag_unset(RFlag *f, RFlagItem *item);
-R_API int r_flag_unset_name(RFlag *f, const char *name);
-R_API int r_flag_unset_off(RFlag *f, ut64 addr);
+R_API bool r_flag_unset(RFlag *f, RFlagItem *item);
+R_API bool r_flag_unset_name(RFlag *f, const char *name);
+R_API bool r_flag_unset_off(RFlag *f, ut64 addr);
 R_API void r_flag_unset_all (RFlag *f);
 R_API RFlagItem *r_flag_set(RFlag *fo, const char *name, ut64 addr, ut32 size);
 R_API RFlagItem *r_flag_set_next(RFlag *fo, const char *name, ut64 addr, ut32 size);
-R_API int r_flag_sort(RFlag *f, int namesort);
+R_API bool r_flag_sort(RFlag *f, int namesort);
 R_API void r_flag_item_set_alias(RFlagItem *item, const char *alias);
 R_API void r_flag_item_free (RFlagItem *item);
 R_API void r_flag_item_set_comment(RFlagItem *item, const char *comment);
@@ -113,8 +124,8 @@ R_API void r_flag_item_set_realname(RFlagItem *item, const char *realname);
 R_API RFlagItem *r_flag_item_clone(RFlagItem *item);
 R_API int r_flag_unset_glob(RFlag *f, const char *name);
 R_API int r_flag_rename(RFlag *f, RFlagItem *item, const char *name);
-R_API int r_flag_relocate (RFlag *f, ut64 off, ut64 off_mask, ut64 to);
-R_API int r_flag_move (RFlag *f, ut64 at, ut64 to);
+R_API int r_flag_relocate(RFlag *f, ut64 off, ut64 off_mask, ut64 to);
+R_API bool r_flag_move (RFlag *f, ut64 at, ut64 to);
 R_API const char *r_flag_color(RFlag *f, RFlagItem *it, const char *color);
 
 /* spaces */
@@ -123,12 +134,12 @@ R_API const char *r_flag_space_get_i(RFlag *f, int idx);
 R_API const char *r_flag_space_cur(RFlag *f);
 R_API int r_flag_space_set(RFlag *f, const char *name);
 R_API bool r_flag_space_set_i(RFlag *f, int idx);
-R_API int r_flag_count (RFlag *f, const char *name);
-R_API int r_flag_space_unset (RFlag *f, const char *fs);
+R_API int r_flag_count(RFlag *f, const char *name);
+R_API int r_flag_space_unset(RFlag *f, const char *fs);
 R_API int r_flag_space_list(RFlag *f, int mode);
-R_API int r_flag_space_rename (RFlag *f, const char *oname, const char *nname);
+R_API bool r_flag_space_rename(RFlag *f, const char *oname, const char *nname);
 R_API bool r_flag_space_pop(RFlag *f);
-R_API int r_flag_space_push(RFlag *f, const char *name);
+R_API bool r_flag_space_push(RFlag *f, const char *name);
 R_API int r_flag_space_stack_list(RFlag *f, int mode);
 
 /* tags */
